@@ -25,6 +25,7 @@ setGeneric("initfunc", function(obj, ...) standardGeneric("initfunc"))
 setGeneric("initfunc<-", function(obj, value) standardGeneric("initfunc<-"))
 
 setGeneric("out", function(obj, ...) standardGeneric("out"))
+setGeneric("out<-", function(obj, value) standardGeneric("out<-"))
 ## the out slot is readonly
 
 setMethod("parms", "simObj",
@@ -158,6 +159,14 @@ setMethod("out", "simObj",
   }
 )
 
+setMethod("out<-", "simObj",
+    function(obj, value) {
+      if(!is.null(value)) stop("``out'' can only be set to NULL")
+      obj@out <- value
+      invisible(obj)
+    }
+)
+
 setMethod("out", "gridModel",
   # if last==TRUE: returns a matrix (identical to init)
   function(obj, last=FALSE) {
